<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../about.ui" line="33"/>
        <source>&amp;Info</source>
        <translation>&amp;Bilgi</translation>
    </message>
    <message>
        <location filename="../about.ui" line="89"/>
        <source>&amp;Translators</source>
        <translation>&amp;Çevirenler</translation>
    </message>
    <message>
        <location filename="../about.ui" line="145"/>
        <source>&amp;License</source>
        <translation>&amp;Lisans</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>YouTube%1 Browser for SMPlayer</source>
        <translation>YouTube%1 Tarayıcı SMPlayer</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="37"/>
        <source>Version: %1</source>
        <translation>Sürüm: %1</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="39"/>
        <source>Portable Edition</source>
        <translation>Taşınabilir Sürüm</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Compiled with Qt %1 (using %2)</source>
        <translation>Qt %1 ile derlendi (%2 kullanılarak)</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Visit our website for updates:</source>
        <translation>Güncellemeler için web adresini ziyaret edin:</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="87"/>
        <source>Many people contributed with translations.</source>
        <translation>Birçok insan çevirilere katkıda bulundu.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="88"/>
        <source>You can also help to translate SMTube into your own language.</source>
        <translation>Ayrıca SMPlayerı kendi dilinize çevirmek için yadım edebilirsiniz.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="89"/>
        <source>Visit %1 and join a translation team.</source>
        <translation>%1 sayfasını ziyaret edip çeviri takımına katılabilirsiniz.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="91"/>
        <source>Click here to know the translators from the transifex teams</source>
        <translation>Transifex takımındaki çevirmenleri görmek için tıkla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="117"/>
        <source>&lt;b&gt;%1&lt;/b&gt; (%2)</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; (%2)</translation>
    </message>
</context>
<context>
    <name>BrowserWindow</name>
    <message>
        <location filename="../browserwindow.cpp" line="112"/>
        <source>Home</source>
        <translation>Anasayfa</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="115"/>
        <source>Navigation</source>
        <translation>Gezinti</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="123"/>
        <source>Zoom +</source>
        <translation>Yakınlaştır +</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="127"/>
        <source>Zoom -</source>
        <translation>Uzaklaştır -</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="131"/>
        <source>&amp;Quit</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="134"/>
        <source>&amp;Navigation</source>
        <translation>&amp;Gezinti</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="146"/>
        <source>&amp;View</source>
        <translation>&amp;Gösterim</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="147"/>
        <source>Toolbar</source>
        <translation>Araç çubuğu</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="151"/>
        <source>Statusbar</source>
        <translation>Durum çubuğu</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="155"/>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="163"/>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="167"/>
        <source>&amp;Update YouTube playback support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="169"/>
        <source>&amp;Install / Update YouTube playback support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="175"/>
        <source>&amp;About SMTube</source>
        <translation>&amp;SMPlayer Hakkında</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="296"/>
        <source>Download video using an external service</source>
        <translation>Videoyu harici servisleri kullanarak indir</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="297"/>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="524"/>
        <source>No video found</source>
        <translation>Video bulunamadı</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="525"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation>Video bağlantısı bulunamadı</translation>
    </message>
    <message>
        <location filename="../browserwindow.cpp" line="282"/>
        <source>Loading... %1%</source>
        <translation>Yükleniyor.. %1%</translation>
    </message>
</context>
<context>
    <name>CodeDownloader</name>
    <message>
        <location filename="../codedownloader.cpp" line="49"/>
        <source>Downloading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="76"/>
        <source>Connecting to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="145"/>
        <source>The YouTube code has been installed successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="146"/>
        <source>Installed version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="147"/>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="152"/>
        <source>It&apos;s not possible to save %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="157"/>
        <source>An error happened while downloading the file:&lt;br&gt;%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="165"/>
        <source>%1 failed to communicate with youtube-dl. Either it&apos;s not installed or it doesn&apos;t work correctly.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="169"/>
        <source>It wasn&apos;t possible to find the URL for this video.</source>
        <translation type="unfinished">Video bağlantısı bulunamadı</translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="170"/>
        <source>Maybe you need to update youtube-dl.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="175"/>
        <location filename="../codedownloader.cpp" line="208"/>
        <source>In order to play YouTube videos, %1 needs an external application called youtube-dl.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="176"/>
        <source>This component needs to be updated frequently.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="177"/>
        <source>You can update it just by reinstalling SMPlayer. The installer will download and install the very latest version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="179"/>
        <source>Install / Update YouTube support</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="209"/>
        <source>%1 can download and install this application for you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="210"/>
        <source>It will be downloaded from the official website and installed in %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="211"/>
        <source>Would you like to proceeed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../codedownloader.cpp" line="215"/>
        <location filename="../codedownloader.cpp" line="218"/>
        <source>Install YouTube support?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="27"/>
        <source>&amp;General</source>
        <translation>&amp;Genel</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="127"/>
        <source>A&amp;dd...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="166"/>
        <source>&amp;Players</source>
        <translation>&amp;Oynatıcılar</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="214"/>
        <source>Add</source>
        <translation>Ekle</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="179"/>
        <source>Up</source>
        <translation>Yukarı</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="33"/>
        <source>Playback</source>
        <translation>Oynatma</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="39"/>
        <source>Preferred &amp;quality:</source>
        <translation>Tercih edilen &amp;kalite:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="94"/>
        <source>Sites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="100"/>
        <source>&amp;Site:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="120"/>
        <source>Edi&amp;t...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="138"/>
        <source>De&amp;lete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="225"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="249"/>
        <source>Edit</source>
        <translation>Düzenle</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="262"/>
        <source>A&amp;dd predefined players</source>
        <translation>&amp;Önceden ayarlı oynatıcı ekle</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="298"/>
        <source>&amp;Interface</source>
        <translation>&amp;Arayüz</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="306"/>
        <source>&amp;Style:</source>
        <translation>&amp;Stil:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="342"/>
        <source>Font:</source>
        <translation>Yazı tipi:</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="356"/>
        <source>C&amp;hange...</source>
        <translation>De&amp;ğiştir...</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="68"/>
        <source>Download</source>
        <translation>İndir</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="74"/>
        <source>Download videos using an &amp;external service</source>
        <translation>Videoyu &amp;harici servisleri kullanarak indir</translation>
    </message>
    <message>
        <location filename="../configdialog.ui" line="190"/>
        <source>Down</source>
        <translation>Aşağı</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="79"/>
        <source>Default</source>
        <translation>Öntanımlı</translation>
    </message>
</context>
<context>
    <name>FileChooser</name>
    <message>
        <location filename="../filechooser.cpp" line="56"/>
        <source>Click to select a file or folder</source>
        <translation>Dosya veya klasör seçmek için tıklayın</translation>
    </message>
</context>
<context>
    <name>MyWebView</name>
    <message>
        <location filename="../mywebview.cpp" line="37"/>
        <source>Open in &amp;YouTube</source>
        <translation>&amp;YouTube&apos;da Aç</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="48"/>
        <source>&amp;Save link...</source>
        <translation>&amp;Bağlantıyı kaydet...</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="51"/>
        <source>Copy &amp;link to clipboard</source>
        <translation>&amp;Bağlantıyı panoya kopyala</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="52"/>
        <source>Open link in this window</source>
        <translation>Bu pencerede linki aç</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="54"/>
        <source>&amp;Copy text to clipboard</source>
        <translation>Metni panoya &amp;kopyala</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="55"/>
        <source>Open link in &amp;new window</source>
        <translation>Bağlantıyı &amp;yeni pencerede aç</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="79"/>
        <source>&amp;Play with</source>
        <translation>&amp;Birlikte yürüt</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="84"/>
        <source>Play &amp;audio with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="137"/>
        <source>&amp;Play with %1</source>
        <translation>%1 ile oynat</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="144"/>
        <source>Play &amp;audio with %1</source>
        <translation>%1 ile &amp;ses çalma</translation>
    </message>
    <message>
        <location filename="../mywebview.cpp" line="151"/>
        <source>Play video with a &amp;web browser</source>
        <translation>&amp;Tarayıcı ile video oynatma</translation>
    </message>
</context>
<context>
    <name>PlayerDialog</name>
    <message>
        <location filename="../playerdialog.ui" line="14"/>
        <source>Edit Player</source>
        <translation>Oynatıcıyı düzenle</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation>&amp;İsim:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="39"/>
        <source>&amp;Executable:</source>
        <translation>&amp;Çalıştırılabilir:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="56"/>
        <source>&amp;Parameters:</source>
        <translation>&amp;Parametreler:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="71"/>
        <source>This player supports &amp;video sites</source>
        <translation>Bu oynatıcı video sitelerini destekler</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="78"/>
        <source>This player can play &amp;online TV</source>
        <translation>Bu oynatıcı çevrimiçi TV oynatabilir</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="87"/>
        <source>Preferred &amp;quality:</source>
        <translation>Tercih edilen &amp;kalite:</translation>
    </message>
    <message>
        <location filename="../playerdialog.ui" line="117"/>
        <source>Add to &amp;menu:</source>
        <translation>&amp;Menüye ekle</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="28"/>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="29"/>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="30"/>
        <source>Audio</source>
        <translation>Ses</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="31"/>
        <source>Video and audio</source>
        <translation>Video ve ses</translation>
    </message>
    <message>
        <location filename="../playerdialog.cpp" line="33"/>
        <source>Default</source>
        <translation>Varsayılan</translation>
    </message>
</context>
<context>
    <name>SiteDialog</name>
    <message>
        <location filename="../sitedialog.ui" line="14"/>
        <source>Edit Site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="22"/>
        <source>&amp;Name:</source>
        <translation type="unfinished">&amp;İsim:</translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="39"/>
        <source>&amp;Home page URL:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sitedialog.ui" line="56"/>
        <source>&amp;Search URL:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
